@@ -1,4 +1,4 @@
-bprobgHsSSPL <- function(params, BivD, nC, nu, sp.xi1, sp.xi2, PL, eqPL, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2){
+bprobgHsSSPL <- function(params, BivD, nC, nu, sp.xi1, sp.xi2, PL, eqPL, valPL, fitPL, H.n, y1.y2, y1.cy2, cy1.y2, cy1.cy2, cy1, X1, X2, weights=weights, X1.d2, X2.d2, pPen1=NULL, pPen2=NULL, sp=NULL, qu.mag=NULL, gp1, gp2, fp, l.sp1, l.sp2){
 
 dl.dlambda1.st <- dl.dlambda2.st <- d2l.be1.lambda1 <- d2l.be1.lambda2 <- d2l.be2.lambda1 <- d2l.be2.lambda2 <- d2l.rho.lambda1 <- d2l.rho.lambda2 <- d2l.lambda1.lambda1 <- d2l.lambda2.lambda2 <- d2l.lambda1.lambda2 <- NA 
 
@@ -7,45 +7,169 @@ dl.dlambda1.st <- dl.dlambda2.st <- d2l.be1.lambda1 <- d2l.be1.lambda2 <- d2l.be
   eta1 <- X1%*%params[1:X1.d2]
   eta2 <- X2%*%params[(X1.d2+1):(X1.d2+X2.d2)]
   teta.st    <- params[(X1.d2+X2.d2+1)]
-  if(eqPL=="both"){  
-    lambda1.st <- params[(X1.d2+X2.d2+2)]
-    lambda2.st <- params[(X1.d2+X2.d2+3)]
-    lambda1 <- exp(lambda1.st)+ epsilon  
-    lambda2 <- exp(lambda2.st)+ epsilon
-  }
-  if(eqPL=="first"){  
-    lambda1.st <- params[(X1.d2+X2.d2+2)]
-    lambda2.st <- 0 
-    lambda1 <- exp(lambda1.st)+ epsilon  
-    lambda2 <- exp(lambda2.st)
-  }
-  if(eqPL=="second"){  
-    lambda1.st <- 0
-    lambda2.st <- params[(X1.d2+X2.d2+2)]
-    lambda1 <- exp(lambda1.st) 
-    lambda2 <- exp(lambda2.st)+ epsilon
+  
+  
+if(PL=="PP" || PL=="RPP"){  
+  
+if(fitPL=="fixed"){
+
+  lambda1.st <- valPL[1]
+  lambda2.st <- valPL[2]
+  lambda1 <- exp(lambda1.st)+ epsilon  
+  lambda2 <- exp(lambda2.st)+ epsilon
+
+}else{
+  
+if(eqPL=="both"){  
+  lambda1.st <- params[(X1.d2+X2.d2+2)]
+  lambda2.st <- params[(X1.d2+X2.d2+3)]
+  lambda1 <- exp(lambda1.st)+ epsilon  
+  lambda2 <- exp(lambda2.st)+ epsilon
+}
+if(eqPL=="first"){  
+  lambda1.st <- params[(X1.d2+X2.d2+2)]
+  lambda2.st <- 0 
+  lambda1 <- exp(lambda1.st)+ epsilon  
+  lambda2 <- exp(lambda2.st)
+}
+if(eqPL=="second"){  
+  lambda1.st <- 0
+  lambda2.st <- params[(X1.d2+X2.d2+2)]
+  lambda1 <- exp(lambda1.st) 
+  lambda2 <- exp(lambda2.st)+ epsilon
+}
+
+}
+
+
+}
+
+if(PL=="SN"){  
+
+if(fitPL=="fixed"){
+
+  lambda1.st <- valPL[1]
+  lambda2.st <- valPL[2]
+  lambda1 <- lambda1.st
+  lambda2 <- lambda2.st
+  del1 <- -lambda1/sqrt(1+lambda1^2)
+  del2 <- -lambda2/sqrt(1+lambda2^2)
+
+}else{
+
+if(eqPL=="both"){  
+  lambda1.st <- params[(X1.d2+X2.d2+2)]
+  lambda2.st <- params[(X1.d2+X2.d2+3)]
+  lambda1 <- lambda1.st
+  lambda2 <- lambda2.st
+  del1 <- -lambda1/sqrt(1+lambda1^2)
+  del2 <- -lambda2/sqrt(1+lambda2^2)
+}
+if(eqPL=="first"){  
+  lambda1.st <- params[(X1.d2+X2.d2+2)]
+  lambda2.st <- 0 
+  lambda1 <- lambda1.st
+  lambda2 <- lambda2.st
+  del1 <- -lambda1/sqrt(1+lambda1^2)
+
+}
+if(eqPL=="second"){  
+  lambda1.st <- 0
+  lambda2.st <- params[(X1.d2+X2.d2+2)]
+  lambda1 <- lambda1.st 
+  lambda2 <- lambda2.st
+  del2 <- -lambda2/sqrt(1+lambda2^2)
+}
+
+}
+
+
+}
+
+  
+  if(PL=="PP"){
+
+    if(eqPL=="both"){
+
+    p1 <- pnorm(eta1)^lambda1
+    p2 <- pnorm(eta2)^lambda2
+    d.n1 <- pnorm(eta1)^(lambda1 - 1) * (lambda1 * dnorm(eta1))
+    d.n2 <- pnorm(eta2)^(lambda2 - 1) * (lambda2 * dnorm(eta2))
+  
+    }
+  
+    if(eqPL=="first"){
+  
+    p1 <- pnorm(eta1)^lambda1
+    p2 <- pnorm(eta2)
+    d.n1 <- pnorm(eta1)^(lambda1 - 1) * (lambda1 * dnorm(eta1))
+    d.n2 <- dnorm(eta2)
+    
+    }
+    
+    if(eqPL=="second"){
+  
+    p1 <- pnorm(eta1)
+    p2 <- pnorm(eta2)^lambda2
+    d.n1 <- dnorm(eta1)
+    d.n2 <- pnorm(eta2)^(lambda2 - 1) * (lambda2 * dnorm(eta2))
+    
+    }    
+  
+ 
   }
 
-  #lambda1 <- xi1 
-  #lambda2 <- xi2
-    
+  if(PL=="RPP"){
+
+
+   if(eqPL=="both"){
+   
+   p1 <- 1-pnorm(-eta1)^lambda1
+   p2 <- 1-pnorm(-eta2)^lambda2
+   d.n1 <- pnorm(-eta1)^(lambda1 - 1) * (lambda1 * dnorm(-eta1))
+   d.n2 <- pnorm(-eta2)^(lambda2 - 1) * (lambda2 * dnorm(-eta2))  
   
-    if(PL=="PP"){
+   }
+   
+   if(eqPL=="first"){
+   
+   p1 <- 1-pnorm(-eta1)^lambda1
+   p2 <- pnorm(eta2)
+   d.n1 <- pnorm(-eta1)^(lambda1 - 1) * (lambda1 * dnorm(-eta1))
+   d.n2 <- dnorm(eta2)  
+  
+   }   
+   
+   if(eqPL=="second"){
+   
+   p1 <- pnorm(eta1)
+   p2 <- 1-pnorm(-eta2)^lambda2
+   d.n1 <- dnorm(eta1)
+   d.n2 <- pnorm(-eta2)^(lambda2 - 1) * (lambda2 * dnorm(-eta2))  
+  
+   }   
+   
+  
+  }
+  
+  
+  
+  if(PL=="SN"){  
   
       if(eqPL=="both"){
   
-      p1 <- pnorm(eta1)^lambda1
-      p2 <- pnorm(eta2)^lambda2
-      d.n1 <- pnorm(eta1)^(lambda1 - 1) * (lambda1 * dnorm(eta1))
-      d.n2 <- pnorm(eta2)^(lambda2 - 1) * (lambda2 * dnorm(eta2))
+      p1 <- 2*pbinorm( eta1, 0, cov12=del1)
+      p2 <- 2*pbinorm( eta2, 0, cov12=del2)
+      d.n1 <- 2*dnorm(eta1)*pnorm(lambda1*eta1)
+      d.n2 <- 2*dnorm(eta2)*pnorm(lambda2*eta2)
     
       }
     
       if(eqPL=="first"){
     
-      p1 <- pnorm(eta1)^lambda1
+      p1 <- 2*pbinorm( eta1, 0, cov12=del1)
       p2 <- pnorm(eta2)
-      d.n1 <- pnorm(eta1)^(lambda1 - 1) * (lambda1 * dnorm(eta1))
+      d.n1 <- 2*dnorm(eta1)*pnorm(lambda1*eta1)
       d.n2 <- dnorm(eta2)
       
       }
@@ -53,47 +177,15 @@ dl.dlambda1.st <- dl.dlambda2.st <- d2l.be1.lambda1 <- d2l.be1.lambda2 <- d2l.be
       if(eqPL=="second"){
     
       p1 <- pnorm(eta1)
-      p2 <- pnorm(eta2)^lambda2
+      p2 <- 2*pbinorm( eta2, 0, cov12=del2)
       d.n1 <- dnorm(eta1)
-      d.n2 <- pnorm(eta2)^(lambda2 - 1) * (lambda2 * dnorm(eta2))
+      d.n2 <- 2*dnorm(eta2)*pnorm(lambda2*eta2)
       
       }    
     
    
-    }
+  }
   
-    if(PL=="RPP"){
-  
-  
-     if(eqPL=="both"){
-     
-     p1 <- 1-pnorm(-eta1)^lambda1
-     p2 <- 1-pnorm(-eta2)^lambda2
-     d.n1 <- pnorm(-eta1)^(lambda1 - 1) * (lambda1 * dnorm(-eta1))
-     d.n2 <- pnorm(-eta2)^(lambda2 - 1) * (lambda2 * dnorm(-eta2))  
-    
-     }
-     
-     if(eqPL=="first"){
-     
-     p1 <- 1-pnorm(-eta1)^lambda1
-     p2 <- pnorm(eta2)
-     d.n1 <- pnorm(-eta1)^(lambda1 - 1) * (lambda1 * dnorm(-eta1))
-     d.n2 <- dnorm(eta2)  
-    
-     }   
-     
-     if(eqPL=="second"){
-     
-     p1 <- pnorm(eta1)
-     p2 <- 1-pnorm(-eta2)^lambda2
-     d.n1 <- dnorm(eta1)
-     d.n2 <- pnorm(-eta2)^(lambda2 - 1) * (lambda2 * dnorm(-eta2))  
-    
-     }   
-     
-    
-    }
   
 
   criteria <- c(0,1)
@@ -142,11 +234,12 @@ c.copula.be1   <- dH$c.copula.be1
 c.copula.be2   <- dH$c.copula.be2
 c.copula.theta <- dH$c.copula.theta 
 
+if(fitPL!="fixed"){
 if(eqPL=="both"){c.copula.lambda1 <- dH$c.copula.lambda1
                  c.copula.lambda2 <- dH$c.copula.lambda2}
 if(eqPL=="first")  c.copula.lambda1 <- dH$c.copula.lambda1
 if(eqPL=="second") c.copula.lambda2 <- dH$c.copula.lambda2
-
+}
 
 c.copula2.be1    <- dH$c.copula2.be1   
 c.copula2.be2    <- dH$c.copula2.be2 
@@ -158,6 +251,8 @@ der.d.n1.be1     <- dH$der.d.n1.be1
 der.d.n2.be2     <- dH$der.d.n2.be2  
 
 
+if(fitPL!="fixed"){
+
 if(eqPL=="both"){
 bit1.lambda1.2       <- dH$bit1.lambda1.2
 bit1.lambda2.2       <- dH$bit1.lambda2.2
@@ -198,6 +293,8 @@ der2.p2.lambda2  <- dH$der2.p2.lambda2
 der.d.n2.lambda2 <- dH$der.d.n2.lambda2
 }
 
+}
+
 
 
 bit1.b1b1 <- c.copula2.be1*(d.n1)^2+c.copula.be1*der.d.n1.be1 
@@ -219,6 +316,9 @@ bit2.b2th <- -bit1.b2th
 bit2.th2 <- -bit1.th2 
 
 
+
+if(fitPL!="fixed"){
+
 if(eqPL=="both"){  
 bit2.lambda1.2 <- der2.p1.lambda1-bit1.lambda1.2
 bit3.lambda1.2 <- -(der2.p1.lambda1*p0+der.p1.lambda1^2)/p0^2
@@ -272,6 +372,8 @@ bit2.be1lambda2 <- -bit1.be1lambda2
 
 bit2.thlambda2 <- -bit1.thlambda2
 
+}
+
 }
 
 
@@ -284,6 +386,8 @@ bit2.thlambda2 <- -bit1.thlambda2
 
   dl.drho <-  weights*( y1.y2*c.copula.theta/p11+y1.cy2*(-c.copula.theta)/p10  )
 
+if(fitPL!="fixed"){
+
 if(eqPL=="both"){
   dl.dlambda1.st <- weights*(y1.y2*c.copula.lambda1/p11+y1.cy2*(der.p1.lambda1-c.copula.lambda1)/p10 - 
                      cy1*der.p1.lambda1/p0) 
@@ -299,6 +403,8 @@ if(eqPL=="second"){
   dl.dlambda2.st <- weights*(y1.y2*c.copula.lambda2/p11+y1.cy2*(-c.copula.lambda2)/p10) 
 }
 
+}
+
 
 
    d2l.be1.be1  <- -weights*(y1.y2*(bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11^2+
@@ -320,6 +426,9 @@ if(eqPL=="second"){
   d2l.rho.rho  <- -weights*(y1.y2*(bit1.th2*p11-c.copula.theta^2)/p11^2+
                               y1.cy2*(bit2.th2*p10-(-c.copula.theta)^2)/p10^2 )
 
+
+if(fitPL!="fixed"){
+
 if(eqPL=="both"){                             
   d2l.be1.lambda1  <- -weights*(y1.y2*(bit1.be1lambda1*p11-(c.copula.be1*d.n1*c.copula.lambda1))/p11^2+
                               y1.cy2*(bit2.be1lambda1*p10-((1-c.copula.be1)*d.n1)*(der.p1.lambda1-c.copula.lambda1))/p10^2+
@@ -391,7 +500,9 @@ if(eqPL=="second"){
   d2l.lambda2.lambda2  <- -weights*(y1.y2*(bit1.lambda2.2*p11-c.copula.lambda2^2)/p11^2+
                               y1.cy2*(bit2.lambda2.2*p10-(-c.copula.lambda2)^2)/p10^2)
                              
-}     
+}   
+
+}  
 
 
   be1.be1 <- crossprod(X1*c(d2l.be1.be1),X1)
@@ -399,6 +510,9 @@ if(eqPL=="second"){
   be1.be2 <- crossprod(X1*c(d2l.be1.be2),X2)
   be1.rho <- t(t(rowSums(t(X1*c(d2l.be1.rho)))))
   be2.rho <- t(t(rowSums(t(X2*c(d2l.be2.rho)))))
+
+if(fitPL!="fixed"){
+
 if(eqPL=="both"){     
   be1.lambda1 <- t(t(rowSums(t(X1*c(d2l.be1.lambda1)))))
   be2.lambda2 <- t(t(rowSums(t(X2*c(d2l.be2.lambda2)))))
@@ -414,6 +528,8 @@ if(eqPL=="second"){
   be1.lambda2 <- t(t(rowSums(t(X1*c(d2l.be1.lambda2)))))
 }
 
+}
+
 
 
   H <- rbind( cbind( be1.be1    , be1.be2    , be1.rho ), 
@@ -427,7 +543,7 @@ if(eqPL=="second"){
 
 
 
-
+if(fitPL!="fixed"){
 
 if(eqPL=="both"){  
 
@@ -480,6 +596,11 @@ G <- -c(G, sum( dl.dlambda2.st ) )
 
 }
 
+}
+
+
+
+
     res <- -sum(l.par)
 
     if(eqPL=="both"){   add.z <- diag(c(1,1)); add.z <- add.z*c(sp.xi1,sp.xi2); nsh <- 2  } 
@@ -521,22 +642,37 @@ if( ( l.sp1==0 && l.sp2==0 ) || fp==TRUE){
     
     lS1 <- length(S1); lS2 <- length(S2) 
     
+if(fitPL!="fixed"){
+
     if(lS1==1 && lS2==1) S.h <- adiag(ma1, ma2, 0, add.z)
     if(lS1 >1 && lS2==1) S.h <- adiag(ma1, S1, ma2, 0, add.z)
     if(lS1==1 && lS2 >1) S.h <- adiag(ma1, ma2, S2, 0, add.z)
     if(lS1 >1 && lS2 >1) S.h <- adiag(ma1, S1, ma2, S2, 0, add.z)
         
+  }else{
+  
+    if(lS1==1 && lS2==1) S.h <- adiag(ma1, ma2, 0)
+    if(lS1 >1 && lS2==1) S.h <- adiag(ma1, S1, ma2, 0)
+    if(lS1==1 && lS2 >1) S.h <- adiag(ma1, ma2, S2, 0)
+    if(lS1 >1 && lS2 >1) S.h <- adiag(ma1, S1, ma2, S2, 0)
+  
+  }
+        
          }
 
    S.h1 <- 0.5*crossprod(params,S.h)%*%params
    S.h2 <- S.h%*%params
 
 
+         if(fitPL=="fixed") G <- -G
+
          S.res <- res
          res <- S.res + S.h1
          G   <- G + S.h2
          H   <- H + S.h  
 
+
+
          list(value=res, gradient=G, hessian=H, S.h=S.h, l=S.res, l.par=l.par, 
               p11=p11, p10=p10, p0=p0, eta1=eta1, eta2=eta2,
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.drho=dl.drho, dl.dlambda1.st=dl.dlambda1.st, dl.dlambda2.st=dl.dlambda2.st,
